package com.bonus.material.ma.service.impl;

import java.util.List;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.ma.mapper.InputRecordMapper;
import com.bonus.material.ma.domain.InputRecord;
import com.bonus.material.ma.service.IInputRecordService;

/**
 * 入库记录Service业务层处理
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Service
public class InputRecordServiceImpl implements IInputRecordService 
{
    @Autowired
    private InputRecordMapper inputRecordMapper;

    /**
     * 查询入库记录
     * 
     * @param id 入库记录主键
     * @return 入库记录
     */
    @Override
    public InputRecord selectInputRecordById(Long id)
    {
        return inputRecordMapper.selectInputRecordById(id);
    }

    /**
     * 查询入库记录列表
     * 
     * @param inputRecord 入库记录
     * @return 入库记录
     */
    @Override
    public List<InputRecord> selectInputRecordList(InputRecord inputRecord)
    {
        return inputRecordMapper.selectInputRecordList(inputRecord);
    }

    /**
     * 新增入库记录
     * 
     * @param inputRecord 入库记录
     * @return 结果
     */
    @Override
    public int insertInputRecord(InputRecord inputRecord)
    {
        inputRecord.setCreateTime(DateUtils.getNowDate());
        return inputRecordMapper.insertInputRecord(inputRecord);
    }

    /**
     * 修改入库记录
     * 
     * @param inputRecord 入库记录
     * @return 结果
     */
    @Override
    public int updateInputRecord(InputRecord inputRecord)
    {
        inputRecord.setUpdateTime(DateUtils.getNowDate());
        return inputRecordMapper.updateInputRecord(inputRecord);
    }

    /**
     * 批量删除入库记录
     * 
     * @param ids 需要删除的入库记录主键
     * @return 结果
     */
    @Override
    public int deleteInputRecordByIds(Long[] ids)
    {
        return inputRecordMapper.deleteInputRecordByIds(ids);
    }

    /**
     * 删除入库记录信息
     * 
     * @param id 入库记录主键
     * @return 结果
     */
    @Override
    public int deleteInputRecordById(Long id)
    {
        return inputRecordMapper.deleteInputRecordById(id);
    }
}
