package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.InputRecord;
import com.bonus.material.ma.service.IInputRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 入库记录Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "入库记录接口")
@RestController
@RequestMapping("/ma_input_record")
public class InputRecordController extends BaseController
{
    @Autowired
    private IInputRecordService inputRecordService;

    /**
     * 查询入库记录列表
     */
    @ApiOperation(value = "查询入库记录列表")
    @RequiresPermissions("ma:record:list")
    @GetMapping("/list")
    public TableDataInfo list(InputRecord inputRecord)
    {
        startPage();
        List<InputRecord> list = inputRecordService.selectInputRecordList(inputRecord);
        return getDataTable(list);
    }

    /**
     * 导出入库记录列表
     */
    @ApiOperation(value = "导出入库记录列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:record:export")
    @SysLog(title = "入库记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出入库记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, InputRecord inputRecord)
    {
        List<InputRecord> list = inputRecordService.selectInputRecordList(inputRecord);
        ExcelUtil<InputRecord> util = new ExcelUtil<InputRecord>(InputRecord.class);
        util.exportExcel(response, list, "入库记录数据");
    }

    /**
     * 获取入库记录详细信息
     */
    @ApiOperation(value = "获取入库记录详细信息")
    @RequiresPermissions("ma:record:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(inputRecordService.selectInputRecordById(id));
    }

    /**
     * 新增入库记录
     */
    @ApiOperation(value = "新增入库记录")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:record:add")
    @SysLog(title = "入库记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增入库记录")
    @PostMapping
    public AjaxResult add(@RequestBody InputRecord inputRecord)
    {
        return toAjax(inputRecordService.insertInputRecord(inputRecord));
    }

    /**
     * 修改入库记录
     */
    @ApiOperation(value = "修改入库记录")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:record:edit")
    @SysLog(title = "入库记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改入库记录")
    @PutMapping
    public AjaxResult edit(@RequestBody InputRecord inputRecord)
    {
        return toAjax(inputRecordService.updateInputRecord(inputRecord));
    }

    /**
     * 删除入库记录
     */
    @ApiOperation(value = "删除入库记录")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:record:remove")
    @SysLog(title = "入库记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除入库记录")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(inputRecordService.deleteInputRecordByIds(ids));
    }
}
